#!/usr/bin/env python3

from datetime import datetime
from flask import Flask
from flask import render_template
from flask import request
from flask_sqlalchemy import SQLAlchemy
from markdown2 import markdown


app = Flask(__name__)

app.config["SQLALCHEMY_DATABASE_URI"] = "sqlite:////tmp/temp.db"
app.config["SQLALCHEMY_TRACK_MODIFICATIONS"] = True

db = SQLAlchemy(app)


class Diary(db.Model):
    """
    Diary object for SQLAlchemy
    """

    id = db.Column(db.Integer, primary_key=True)
    date = db.Column(db.DateTime(), index=True, default=datetime.now)
    content = db.Column(db.String(), unique=True)

    def __repr__(self):
        return f"<Diary {self.id}>"


@app.route("/")
def index():
    """
    Route for index page.
    """
    return render_template("index.html", diaries=Diary.query.all())


@app.route("/add")
def add_page():
    """
    Route for adding new diaries.
    """
    return render_template("add.html")


@app.route("/add/successful", methods=["POST"])
def add_page_successful():
    """
    Route for the page to add the diary & show the operation is successful.
    """
    if request.method == "POST":
        diary_content = request.form["diaryContent"]
        new_diary = Diary(content=markdown(diary_content))
        db.session.add(new_diary)
        db.session.commit()
    return render_template("add_successful.html")


@app.route("/diaries/<int:diary_id>")
def read_diary(diary_id):
    """
    Route for reading the diaries.
    """
    return render_template("read_diary.html", diary=Diary.query.get(diary_id))

@app.errorhandler(404)
def page_not_found(error):
    """
    Route for error page.
    """
    return render_template("404.html"), error


app.run(debug=True)
